"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meta import Meta, MetaTypedDict
from typing import Any, Dict, List
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2AnalyticsGetVerificationsResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: List[Dict[str, Any]]
    r"""Array of verification rows returned by the query. Fields vary based on the SQL SELECT clause."""


class V2AnalyticsGetVerificationsResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: List[Dict[str, Any]]
    r"""Array of verification rows returned by the query. Fields vary based on the SQL SELECT clause."""
