"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2AnalyticsGetVerificationsRequestBodyTypedDict(TypedDict):
    query: str
    r"""SQL query to execute against your analytics data.
    Only SELECT queries are allowed.

    """


class V2AnalyticsGetVerificationsRequestBody(BaseModel):
    query: str
    r"""SQL query to execute against your analytics data.
    Only SELECT queries are allowed.

    """
